@@ -1443,6 +1443,7 @@ static void category_selected (GtkTreeView *tv, gpointer ptr)
     GtkTreeModel *model;
     GtkTreePath *path;
     GtkTreeSelection *sel;
+    GtkTreeViewColumn *col;
     GtkTreeIter iter;
 
     // store the path of the new selection so it can be reloaded
@@ -1457,8 +1458,10 @@ static void category_selected (GtkTreeView *tv, gpointer ptr)
 
     model = gtk_tree_view_get_model (GTK_TREE_VIEW (pack_tv));
     path = gtk_tree_path_new_first ();
+    col = gtk_tree_view_get_column (GTK_TREE_VIEW (pack_tv), 2);
     gtk_tree_model_filter_refilter (GTK_TREE_MODEL_FILTER (model));
     gtk_tree_view_scroll_to_cell (GTK_TREE_VIEW (pack_tv), path, NULL, TRUE, 0.0, 0.0);
+    gtk_tree_view_set_cursor (GTK_TREE_VIEW (pack_tv), path, col, FALSE);
     gtk_tree_path_free (path);
 }
 
